@@ -5,6 +5,7 @@ matebg.c: Object for the desktop background.
 Copyright (C) 2000 Eazel, Inc.
 Copyright (C) 2007-2008 Red Hat, Inc.
 Copyright (C) 2012 Jasmine Hassan <jasmine.aura@gmail.com>
+Copyright (C) 2012-2021 MATE Developers
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License as
@@ -195,15 +196,10 @@ static FileSize   *find_best_size      (GSList                *sizes,
 
 static void
 color_from_string (const char *string,
-		   GdkRGBA   *colorp)
+                   GdkRGBA    *colorp)
 {
-	/* If all else fails use black */
-	gdk_rgba_parse (colorp, "#000000");
-
-	if (!string)
-		return;
-
-	gdk_rgba_parse (colorp, string);
+	if (!string || *string == '\0' || !gdk_rgba_parse (colorp, string))
+		gdk_rgba_parse (colorp, "#000000"); /* If all else fails use black */
 }
 
 static char *
@@ -403,8 +399,7 @@ mate_bg_load_from_gsettings (MateBG    *bg,
 	mate_bg_set_placement (bg, placement);
 	mate_bg_set_filename (bg, filename);
 
-	if (filename != NULL)
-		g_free (filename);
+	g_free (filename);
 }
 
 void
@@ -615,7 +610,7 @@ mate_bg_get_filename (MateBG *bg)
 }
 
 static inline gchar *
-get_wallpaper_cache_dir ()
+get_wallpaper_cache_dir (void)
 {
 	return g_build_filename (g_get_user_cache_dir(), MATE_BG_CACHE_DIR, NULL);
 }
@@ -2375,12 +2370,14 @@ get_pixbuf_for_size (MateBG *bg,
 
 			if (show) {
 				double alpha;
+				double timeout;
 				Slide *slide;
 
 				slideshow_ref (show);
 
 				slide = get_current_slide (show, &alpha);
-				time_until_next_change = (guint)get_slide_timeout (slide);
+				timeout = get_slide_timeout (slide);
+				time_until_next_change = (guint) timeout;
 				if (slide->fixed) {
 					FileSize *size = find_best_size (slide->file1,
 									 best_width, best_height);
@@ -2972,10 +2969,7 @@ slideshow_unref (SlideShow *show)
 	}
 
 	g_queue_free (show->slides);
-
-	g_list_foreach (show->stack->head, (GFunc) g_free, NULL);
-	g_queue_free (show->stack);
-
+	g_queue_free_full (show->stack, g_free);
 	g_free (show);
 }
 
@@ -3078,7 +3072,7 @@ read_slideshow_file (const char *filename,
 	g_markup_parse_context_free (context);
 
 	if (show) {
-		int len;
+		guint num_items;
 
 		t = mktime (&show->start_tm);
 
@@ -3086,14 +3080,14 @@ read_slideshow_file (const char *filename,
 
 		dump_bg (show);
 
-		len = g_queue_get_length (show->slides);
+		num_items = g_queue_get_length (show->slides);
 
 		/* no slides, that's not a slideshow */
-		if (len == 0) {
+		if (num_items == 0) {
 			slideshow_unref (show);
 			show = NULL;
 		/* one slide, there's no transition */
-		} else if (len == 1) {
+		} else if (num_items == 1) {
 			Slide *slide = show->slides->head->data;
 			slide->duration = show->total_duration = G_MAXUINT;
 		}
