@@ -376,9 +376,7 @@ fill_screen_info_from_resources (ScreenInfo *info,
     a = g_ptr_array_new ();
     for (i = 0; i < resources->ncrtc; ++i)
     {
-	MateRRCrtc *crtc = crtc_new (info, resources->crtcs[i]);
-
-	g_ptr_array_add (a, crtc);
+	g_ptr_array_add (a, crtc_new (info, resources->crtcs[i]));
     }
     g_ptr_array_add (a, NULL);
     info->crtcs = (MateRRCrtc **)g_ptr_array_free (a, FALSE);
@@ -386,9 +384,7 @@ fill_screen_info_from_resources (ScreenInfo *info,
     a = g_ptr_array_new ();
     for (i = 0; i < resources->noutput; ++i)
     {
-	MateRROutput *output = output_new (info, resources->outputs[i]);
-
-	g_ptr_array_add (a, output);
+	g_ptr_array_add (a, output_new (info, resources->outputs[i]));
     }
     g_ptr_array_add (a, NULL);
     info->outputs = (MateRROutput **)g_ptr_array_free (a, FALSE);
@@ -1157,7 +1153,11 @@ get_property (Display *dpy,
 
     if (actual_type == XA_INTEGER && actual_format == 8)
     {
+#ifdef GLIB_VERSION_2_68
+	result = g_memdup2 (prop, nitems);
+#else
 	result = g_memdup (prop, nitems);
+#endif
 	if (len)
 	    *len = nitems;
     }
@@ -1363,8 +1363,11 @@ output_copy (const MateRROutput *from)
     output->modes = (MateRRMode**) g_ptr_array_free (array, FALSE);
 
     output->edid_size = from->edid_size;
+#ifdef GLIB_VERSION_2_68
+    output->edid_data = g_memdup2 (from->edid_data, from->edid_size);
+#else
     output->edid_data = g_memdup (from->edid_data, from->edid_size);
-
+#endif
     return output;
 }
 
