@@ -20,15 +20,6 @@
 
 #include "mate-about.h"
 
-/* get text macro, this should be on the common macros. or not?
- */
-#ifndef mate_gettext
-#define mate_gettext(package, locale, codeset) \
-    bindtextdomain(package, locale); \
-    bind_textdomain_codeset(package, codeset); \
-    textdomain(package);
-#endif
-
 static void mate_about_on_activate(GtkApplication* app)
 {
     GList* list;
@@ -66,7 +57,8 @@ void mate_about_run(void)
      * This generate a random message.
      * The comments index must not be more than comments_count - 1
      */
-    gtk_about_dialog_set_comments(mate_about_dialog, gettext(comments_array[g_random_int_range(0, comments_count - 1)]));
+    gtk_about_dialog_set_comments (mate_about_dialog,
+                                   _(comments_array[g_random_int_range (0, comments_count)]));
 
     gtk_about_dialog_set_authors(mate_about_dialog, authors);
     gtk_about_dialog_set_artists(mate_about_dialog, artists);
@@ -86,7 +78,9 @@ int main(int argc, char** argv)
 {
     int status = 0;
 
-    mate_gettext(GETTEXT_PACKAGE, LOCALE_DIR, "UTF-8");
+    bindtextdomain (GETTEXT_PACKAGE, LOCALE_DIR);
+    bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+    textdomain (GETTEXT_PACKAGE);
 
     GOptionContext* context = g_option_context_new(NULL);
     g_option_context_add_main_entries(context, command_entries, GETTEXT_PACKAGE);
@@ -96,7 +90,7 @@ int main(int argc, char** argv)
 
     if (mate_about_nogui == TRUE)
     {
-        printf("%s %s\n", gettext(program_name), version);
+        g_print ("%s %s\n", _(program_name), version);
     }
     else
     {
